# EasYOLOD

A simplified YOLO implementation package.

## Installation

You can install the package from PyPI:

```bash

pip install easyolod
```
Or install the latest development version from GitHub:
```bash

pip install git+https://github.com/zaixia108/easyolo.git
```

Requirements
+ Python 3.8-3.12
+ opencv-python <= 4.10.0.84
+ numpy <= 1.26
